==> jaguar_query-0.0.15.tar.gz: lib/src/core/values/values.dart <==
part of query;

/// An interface for Literal value. Also contains static methods to
abstract class L<ValType> implements Valuable<ValType> {
  /// DSL to create integer literal values
  static LInt Int(int val) => new LInt(val);

  /// DSL to create integer literal values
  static LBool Bool(bool val) => new LBool(val);

  /// DSL to create string literal values
  static LStr Str(String val) => new LStr(val);

  /// DSL to create double literal values
  static LDateTime DateTime(core.DateTime val) => new LDateTime(val);

  /// DSL to create double literal values
  static LDouble Double(double val) => new LDouble(val);

  static L<ValType> Make<ValType>(final ValType val) {
    if (ValType is int) {
      return new LInt(val as int) as L<ValType>;
    } else if (ValType is String) {
      return Str(val as String) as L<ValType>;
    } else if (ValType is core.DateTime) {
      return DateTime(val as core.DateTime) as L<ValType>;
    } else if (ValType is double) {
      return Double(val as double) as L<ValType>;
    } else {
      throw new Exception("Unknown type!");
    }
  }
}

class Column<ValType> implements Valuable<ValType> {
  final String field;

  final String tableAlias;

  const Column(this.field, [this.tableAlias]);

  String toSql() => (tableAlias != null ? tableAlias + '.' : '') + '$field';

  /// DSL to create 'is equal to' relational condition
  Cond<ValType> eq(ValType rhs) => Cond.eq<ValType>(this, L.Make(rhs));

  /// DSL to create 'is equal to' relational condition
  Cond<ValType> eqC(Column<ValType> rhs) => Cond.eq<ValType>(this, rhs);

  /// DSL to create 'is equal to' relational condition
  Cond<ValType> eqV(Valuable<ValType> rhs) => Cond.eq<ValType>(this, rhs);
}

class IntC extends Column<int> {
  const IntC(String field, [String tableAlias]) : super(field, tableAlias);

  String toSql() => (tableAlias != null ? tableAlias + '.' : '') + '$field';

  /// DSL to create 'is equal to' relational condition
  Cond<int> eq(int rhs) => Cond.eq<int>(this, L.Int(rhs));

  static Cond<int> eqL(String field, int rhs) =>
      Cond.eq<int>(C<int>(field), L.Int(rhs));
}

Column<ValType> C<ValType>(String field, [String tableName]) =>
    new Column<ValType>(field, tableName);

/// Integer literal value
class LBool implements L<bool> {
  /// The literal value
  final bool value;

  const LBool(this.value);

  String toSql() => value ? 'TRUE' : 'FALSE';

  /// DSL to create 'is equal to' relational condition
  static Cond<bool> eq(String field, bool rhs) => q.eqBool(field, rhs);

  /// DSL to create 'is not equal to' relational condition
  static Cond<bool> ne(String field, bool rhs) => q.neBool(field, rhs);

  /// DSL to create 'is equal to' relational condition
  static Cond<bool> eqC(String field, Column<bool> column) =>
      q.eqC<bool>(field, column);
}

/// Integer literal value
class LInt implements L<int> {
  /// The literal value
  final int value;

  const LInt(this.value);

  String toSql() => '$value';

  /// DSL to create 'is equal to' relational condition
  static Cond<int> eq(String field, int rhs) => q.eqInt(field, rhs);

  /// DSL to create 'is not equal to' relational condition
  static Cond<int> ne(String field, int value) => q.neInt(field, value);

  /// DSL to create 'is greater than' relational condition
  static Cond<int> gt(String field, int value) => q.gtInt(field, value);

  /// DSL to create 'is greater than or equal to' relational condition
  static Cond<int> gtEq(String field, int value) => q.gtEqInt(field, value);

  /// DSL to create 'is less than or equal to' relational condition
  static Cond<int> ltEq(String field, int value) => q.ltEqInt(field, value);

  /// DSL to create 'is less than' relational condition
  static Cond<int> lt(String field, int value) => q.ltInt(field, value);

  /// DSL to create 'in-between' relational condition
  static InBetweenExpression<int> inBetween(String field, int low, int high) =>
      q.inBetweenInt(field, low, high);

  /// DSL to create 'is equal to' relational condition
  static Cond<int> eqC(String field, Column<int> column) =>
      q.eqC<int>(field, column);
}

/// Double literal value
class LDouble implements L<double> {
  /// The literal value
  final double value;

  const LDouble(this.value);

  String toSql() => '$value';

  /// DSL to create 'is equal to' relational condition
  static Cond<double> eq(String field, double value) =>
      q.eqV<double>(field, L.Double(value));

  /// DSL to create 'is not equal to' relational condition
  static Cond<double> ne(String field, double value) =>
      q.neV<double>(field, L.Double(value));

  /// DSL to create 'is greater than' relational condition
  static Cond<double> gt(String field, double value) =>
      q.gtV<double>(field, L.Double(value));

  /// DSL to create 'is greater than or equal to' relational condition
  static Cond<double> gtEq(String field, double value) =>
      q.gtEqV<double>(field, L.Double(value));

  /// DSL to create 'is less than or equal to' relational condition
  static Cond<double> ltEq(String field, double value) =>
      q.ltEqV<double>(field, L.Double(value));

  /// DSL to create 'is less than' relational condition
  static Cond<double> lt(String field, double value) =>
      q.ltV<double>(field, L.Double(value));

  /// DSL to create 'in-between' relational condition
  static InBetweenExpression<double> inBetween(
          String field, double low, double high) =>
      q.inBetweenV<double>(field, L.Double(low), L.Double(high));
}

/// DateTime literal value
class LDateTime implements L<DateTime> {
  /// The literal value
  final DateTime value;

  const LDateTime(this.value);

  String toSql() => '$value'; //TODO

  /// DSL to create 'is equal to' relational condition
  static Cond<DateTime> eq(String field, DateTime value) =>
      q.eqV<DateTime>(field, L.DateTime(value));

  /// DSL to create 'is not equal to' relational condition
  static Cond<DateTime> ne(String field, DateTime value) =>
      q.neV<DateTime>(field, L.DateTime(value));

  /// DSL to create 'is greater than' relational condition
  static Cond<DateTime> gt(String field, DateTime value) =>
      q.gtV<DateTime>(field, L.DateTime(value));

  /// DSL to create 'is greater than or equal to' relational condition
  static Cond<DateTime> gtEq(String field, DateTime value) =>
      q.gtEqV<DateTime>(field, L.DateTime(value));

  /// DSL to create 'is less than or equal to' relational condition
  static Cond<DateTime> ltEq(String field, DateTime value) =>
      q.ltEqV<DateTime>(field, L.DateTime(value));

  /// DSL to create 'is less than' relational condition
  static Cond<DateTime> lt(String field, DateTime value) =>
      q.ltV<DateTime>(field, L.DateTime(value));

  /// DSL to create 'in-between' relational condition
  static InBetweenExpression<DateTime> inBetween(
          String field, DateTime low, DateTime high) =>
      q.inBetweenV<DateTime>(field, L.DateTime(low), L.DateTime(high));
}

/// String literal value
class LStr implements L<String> {
  /// The literal value
  final String value;

  const LStr(this.value);

  String toSql() => "'$value'";

  /// DSL to create 'is equal to' relational condition
  static Cond<String> eq(String field, String value) => q.eqStr(field, value);

  /// DSL to create 'is not equal to' relational condition
  static Cond<String> ne(String field, String value) => q.neStr(field, value);

  /// DSL to create 'is greater than' relational condition
  static Cond<String> gt(String field, String value) => q.gtStr(field, value);

  /// DSL to create 'is greater than or equal to' relational condition
  static Cond<String> gtEq(String field, String value) =>
      q.gtEqStr(field, value);

  /// DSL to create 'is less than or equal to' relational condition
  static Cond<String> ltEq(String field, String value) =>
      q.ltEqStr(field, value);

  /// DSL to create 'is less than' relational condition
  static Cond<String> lt(String field, String value) => q.ltStr(field, value);

  /// DSL to create 'is like' relational condition
  static Cond<String> like(String field, String value) => q.like(field, value);

  /// DSL to create 'in-between' relational condition
  static InBetweenExpression<String> inBetween(
          String field, String low, String high) =>
      q.inBetweenStr(field, low, high);
}

==> jaguar_query-0.0.16.tar.gz: lib/src/core/values/values.dart <==
part of query;

/// An interface for Literal value. Also contains static methods to
abstract class L<ValType> implements Valuable<ValType> {
  /// DSL to create integer literal values
  static LInt Int(int val) => new LInt(val);

  /// DSL to create integer literal values
  static LBool Bool(bool val) => new LBool(val);

  /// DSL to create string literal values
  static LStr Str(String val) => new LStr(val);

  /// DSL to create double literal values
  static LDateTime DateTime(core.DateTime val) => new LDateTime(val);

  /// DSL to create double literal values
  static LDouble Double(double val) => new LDouble(val);

  static L<ValType> Make<ValType>(final ValType val) {
    if (ValType == int) {
      return new LInt(val as int) as L<ValType>;
    } else if (ValType == String) {
      return Str(val as String) as L<ValType>;
    } else if (ValType == core.DateTime) {
      return DateTime(val as core.DateTime) as L<ValType>;
    } else if (ValType == double) {
      return Double(val as double) as L<ValType>;
    } else {
      throw new Exception("Unknown type!");
    }
  }
}

class Column<ValType> implements Valuable<ValType> {
  final String field;

  final String tableAlias;

  const Column(this.field, [this.tableAlias]);

  String toSql() => (tableAlias != null ? tableAlias + '.' : '') + '$field';

  /// DSL to create 'is equal to' relational condition
  Cond<ValType> eq(ValType rhs) => Cond.eq<ValType>(this, L.Make(rhs));

  /// DSL to create 'is equal to' relational condition
  Cond<ValType> eqC(Column<ValType> rhs) => Cond.eq<ValType>(this, rhs);

  /// DSL to create 'is equal to' relational condition
  Cond<ValType> eqV(Valuable<ValType> rhs) => Cond.eq<ValType>(this, rhs);
}

class IntC extends Column<int> {
  const IntC(String field, [String tableAlias]) : super(field, tableAlias);

  String toSql() => (tableAlias != null ? tableAlias + '.' : '') + '$field';

  /// DSL to create 'is equal to' relational condition
  Cond<int> eq(int rhs) => Cond.eq<int>(this, L.Int(rhs));

  static Cond<int> eqL(String field, int rhs) =>
      Cond.eq<int>(C<int>(field), L.Int(rhs));
}

Column<ValType> C<ValType>(String field, [String tableName]) =>
    new Column<ValType>(field, tableName);

/// Integer literal value
class LBool implements L<bool> {
  /// The literal value
  final bool value;

  const LBool(this.value);

  String toSql() => value ? 'TRUE' : 'FALSE';

  /// DSL to create 'is equal to' relational condition
  static Cond<bool> eq(String field, bool rhs) => q.eqBool(field, rhs);

  /// DSL to create 'is not equal to' relational condition
  static Cond<bool> ne(String field, bool rhs) => q.neBool(field, rhs);

  /// DSL to create 'is equal to' relational condition
  static Cond<bool> eqC(String field, Column<bool> column) =>
      q.eqC<bool>(field, column);
}

/// Integer literal value
class LInt implements L<int> {
  /// The literal value
  final int value;

  const LInt(this.value);

  String toSql() => '$value';

  /// DSL to create 'is equal to' relational condition
  static Cond<int> eq(String field, int rhs) => q.eqInt(field, rhs);

  /// DSL to create 'is not equal to' relational condition
  static Cond<int> ne(String field, int value) => q.neInt(field, value);

  /// DSL to create 'is greater than' relational condition
  static Cond<int> gt(String field, int value) => q.gtInt(field, value);

  /// DSL to create 'is greater than or equal to' relational condition
  static Cond<int> gtEq(String field, int value) => q.gtEqInt(field, value);

  /// DSL to create 'is less than or equal to' relational condition
  static Cond<int> ltEq(String field, int value) => q.ltEqInt(field, value);

  /// DSL to create 'is less than' relational condition
  static Cond<int> lt(String field, int value) => q.ltInt(field, value);

  /// DSL to create 'in-between' relational condition
  static InBetweenExpression<int> inBetween(String field, int low, int high) =>
      q.inBetweenInt(field, low, high);

  /// DSL to create 'is equal to' relational condition
  static Cond<int> eqC(String field, Column<int> column) =>
      q.eqC<int>(field, column);
}

/// Double literal value
class LDouble implements L<double> {
  /// The literal value
  final double value;

  const LDouble(this.value);

  String toSql() => '$value';

  /// DSL to create 'is equal to' relational condition
  static Cond<double> eq(String field, double value) =>
      q.eqV<double>(field, L.Double(value));

  /// DSL to create 'is not equal to' relational condition
  static Cond<double> ne(String field, double value) =>
      q.neV<double>(field, L.Double(value));

  /// DSL to create 'is greater than' relational condition
  static Cond<double> gt(String field, double value) =>
      q.gtV<double>(field, L.Double(value));

  /// DSL to create 'is greater than or equal to' relational condition
  static Cond<double> gtEq(String field, double value) =>
      q.gtEqV<double>(field, L.Double(value));

  /// DSL to create 'is less than or equal to' relational condition
  static Cond<double> ltEq(String field, double value) =>
      q.ltEqV<double>(field, L.Double(value));

  /// DSL to create 'is less than' relational condition
  static Cond<double> lt(String field, double value) =>
      q.ltV<double>(field, L.Double(value));

  /// DSL to create 'in-between' relational condition
  static InBetweenExpression<double> inBetween(
          String field, double low, double high) =>
      q.inBetweenV<double>(field, L.Double(low), L.Double(high));
}

/// DateTime literal value
class LDateTime implements L<DateTime> {
  /// The literal value
  final DateTime value;

  const LDateTime(this.value);

  String toSql() => '$value'; //TODO

  /// DSL to create 'is equal to' relational condition
  static Cond<DateTime> eq(String field, DateTime value) =>
      q.eqV<DateTime>(field, L.DateTime(value));

  /// DSL to create 'is not equal to' relational condition
  static Cond<DateTime> ne(String field, DateTime value) =>
      q.neV<DateTime>(field, L.DateTime(value));

  /// DSL to create 'is greater than' relational condition
  static Cond<DateTime> gt(String field, DateTime value) =>
      q.gtV<DateTime>(field, L.DateTime(value));

  /// DSL to create 'is greater than or equal to' relational condition
  static Cond<DateTime> gtEq(String field, DateTime value) =>
      q.gtEqV<DateTime>(field, L.DateTime(value));

  /// DSL to create 'is less than or equal to' relational condition
  static Cond<DateTime> ltEq(String field, DateTime value) =>
      q.ltEqV<DateTime>(field, L.DateTime(value));

  /// DSL to create 'is less than' relational condition
  static Cond<DateTime> lt(String field, DateTime value) =>
      q.ltV<DateTime>(field, L.DateTime(value));

  /// DSL to create 'in-between' relational condition
  static InBetweenExpression<DateTime> inBetween(
          String field, DateTime low, DateTime high) =>
      q.inBetweenV<DateTime>(field, L.DateTime(low), L.DateTime(high));
}

/// String literal value
class LStr implements L<String> {
  /// The literal value
  final String value;

  const LStr(this.value);

  String toSql() => "'$value'";

  /// DSL to create 'is equal to' relational condition
  static Cond<String> eq(String field, String value) => q.eqStr(field, value);

  /// DSL to create 'is not equal to' relational condition
  static Cond<String> ne(String field, String value) => q.neStr(field, value);

  /// DSL to create 'is greater than' relational condition
  static Cond<String> gt(String field, String value) => q.gtStr(field, value);

  /// DSL to create 'is greater than or equal to' relational condition
  static Cond<String> gtEq(String field, String value) =>
      q.gtEqStr(field, value);

  /// DSL to create 'is less than or equal to' relational condition
  static Cond<String> ltEq(String field, String value) =>
      q.ltEqStr(field, value);

  /// DSL to create 'is less than' relational condition
  static Cond<String> lt(String field, String value) => q.ltStr(field, value);

  /// DSL to create 'is like' relational condition
  static Cond<String> like(String field, String value) => q.like(field, value);

  /// DSL to create 'in-between' relational condition
  static InBetweenExpression<String> inBetween(
          String field, String low, String high) =>
      q.inBetweenStr(field, low, high);
}
